@@ -18,6 +18,7 @@
 #include <mobius/database/statement.h>
 #include <mobius/database/database.h>
 #include <mobius/database/exception.inc>
+#include <mobius/datetime/conv_iso_string.h>
 #include <sqlite3.h>
 #include <thread>
 #include <chrono>
@@ -126,7 +127,7 @@ statement::bind (int idx, const std::string& value)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief bind bytearray value
+//! \brief Bind bytearray value
 //! \param idx value index
 //! \param v value
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -138,7 +139,21 @@ statement::bind (int idx, const mobius::bytearray& value)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief bind null value
+//! \brief Bind datetime value
+//! \param idx Value index
+//! \param v Value
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+void
+statement::bind (int idx, const mobius::datetime::datetime& value)
+{
+  auto timestamp = mobius::datetime::datetime_to_iso_string (value);
+
+  if (sqlite3_bind_text (impl_->stmt, idx, timestamp.c_str (), timestamp.length (), SQLITE_STATIC) != SQLITE_OK)
+    throw std::runtime_error (MOBIUS_EXCEPTION_SQLITE);
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Bind null value
 //! \param idx value index
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
@@ -149,7 +164,7 @@ statement::bind_null (int idx)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief execute statement
+//! \brief Execute statement
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 statement::execute ()
@@ -164,7 +179,7 @@ statement::execute ()
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief fetch one row
+//! \brief Fetch one row
 //! \return true if a row has been found
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bool
@@ -189,7 +204,7 @@ statement::fetch_row ()
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief get number of columns returned by statement
+//! \brief Get number of columns returned by statement
 //! \return number of columns
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 int
@@ -199,7 +214,7 @@ statement::get_column_count ()
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief check whether column value is null
+//! \brief Check whether column value is null
 //! \param idx value index
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bool
@@ -209,7 +224,7 @@ statement::is_column_null (int idx)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief get int column value
+//! \brief Get int column value
 //! \param idx value index
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 int
@@ -219,7 +234,7 @@ statement::get_column_int (int idx)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief get int64_t column value
+//! \brief Get int64_t column value
 //! \param idx value index
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 std::int64_t
@@ -229,7 +244,7 @@ statement::get_column_int64 (int idx)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief get double column value
+//! \brief Get double column value
 //! \param idx value index
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 double
@@ -239,13 +254,13 @@ statement::get_column_double (int idx)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief get string column value
+//! \brief Get string column value
 //! \param idx value index
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 std::string
 statement::get_column_string (int idx)
 {
-  const char *p_text = reinterpret_cast<const char *> (sqlite3_column_text (impl_->stmt, idx));
+  const char *p_text = reinterpret_cast <const char *> (sqlite3_column_text (impl_->stmt, idx));
   std::string value;
 
   if (p_text != nullptr)
@@ -255,7 +270,7 @@ statement::get_column_string (int idx)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief get bytearray column value
+//! \brief Get bytearray column value
 //! \param idx value index
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::bytearray
@@ -273,7 +288,24 @@ statement::get_column_bytearray (int idx)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief get database error message
+//! \brief Get datetime column value
+//! \param idx value index
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+mobius::datetime::datetime
+statement::get_column_datetime (int idx)
+{
+  mobius::datetime::datetime value;
+
+  const char *p_text = reinterpret_cast <const char *> (sqlite3_column_text (impl_->stmt, idx));
+
+  if (p_text != nullptr)
+    value = mobius::datetime::new_datetime_from_iso_string (p_text);
+
+  return value;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Get database error message
 //! \return error message
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 std::string
@@ -283,7 +315,7 @@ statement::get_error_message () const
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief execute a statement step
+//! \brief Execute a statement step
 //! \return sqlite error code
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 int
